@@ -1,3 +1,5 @@
+from __future__ import division, unicode_literals
+from future.builtins import str
 
 from copy import copy
 
@@ -71,6 +73,14 @@ class BaseGenericRelation(GenericRelation):
             for (name_string, field) in self.fields.items():
                 if "%s" in name_string:
                     name_string = name_string % name
+                # In Django 1.6, add_to_class will be called on a
+                # parent model's field more than once, so
+                # contribute_to_class needs to be idempotent. We
+                # don't call get_all_field_names() which fill the app
+                # cache get_fields_with_model() is safe.
+                if name_string in [i.name for i, _ in
+                                   cls._meta.get_fields_with_model()]:
+                    continue
                 if not field.verbose_name:
                     field.verbose_name = self.verbose_name
                 cls.add_to_class(name_string, copy(field))
@@ -96,7 +106,7 @@ class BaseGenericRelation(GenericRelation):
         # since we don't specify a sender for the signal.
         try:
             to = self.rel.to
-            if isinstance(to, basestring):
+            if isinstance(to, str):
                 to = get_model(*to.split(".", 1))
             if not isinstance(kwargs["instance"], to):
                 raise TypeError
@@ -145,7 +155,8 @@ class CommentsField(BaseGenericRelation):
             count = related_manager.count_queryset()
         except AttributeError:
             count = related_manager.count()
-        count_field_name = self.fields.keys()[0] % self.related_field_name
+        count_field_name = list(self.fields.keys())[0] % \
+                           self.related_field_name
         setattr(instance, count_field_name, count)
         instance.save()
 
@@ -212,7 +223,8 @@ class KeywordsField(BaseGenericRelation):
         ``KEYWORDS_FIELD_string`` field in ``search_fields``.
         """
         super(KeywordsField, self).contribute_to_class(cls, name)
-        string_field_name = self.fields.keys()[0] % self.related_field_name
+        string_field_name = list(self.fields.keys())[0] % \
+                            self.related_field_name
         if hasattr(cls, "search_fields") and name in cls.search_fields:
             try:
                 weight = cls.search_fields[name]
@@ -232,8 +244,9 @@ class KeywordsField(BaseGenericRelation):
         Stores the keywords as a single string for searching.
         """
         assigned = related_manager.select_related("keyword")
-        keywords = " ".join([unicode(a.keyword) for a in assigned])
-        string_field_name = self.fields.keys()[0] % self.related_field_name
+        keywords = " ".join([str(a.keyword) for a in assigned])
+        string_field_name = list(self.fields.keys())[0] % \
+                            self.related_field_name
         if getattr(instance, string_field_name) != keywords:
             setattr(instance, string_field_name, keywords)
             instance.save()
@@ -258,7 +271,7 @@ class RatingField(BaseGenericRelation):
         ratings = [r.value for r in related_manager.all()]
         count = len(ratings)
         _sum = sum(ratings)
-        average = _sum / float(count) if count > 0 else 0
+        average = _sum / count if count > 0 else 0
         setattr(instance, "%s_count" % self.related_field_name, count)
         setattr(instance, "%s_sum" % self.related_field_name, _sum)
         setattr(instance, "%s_average" % self.related_field_name, average)
