@@ -1,3 +1,4 @@
+from __future__ import unicode_literals
 
 import os
 
@@ -20,5 +21,5 @@ def import_dotted_path(path):
         module_path, member_name = path.rsplit(".", 1)
         module = import_module(module_path)
         return getattr(module, member_name)
-    except (ValueError, ImportError, AttributeError), e:
+    except (ValueError, ImportError, AttributeError) as e:
         raise ImportError("Could not import the name: %s: %s" % (path, e))
